@@ -36,7 +36,10 @@ def clause_tokenize(doc: List[str]) -> List[List[str]]:
         ['และ', 'คุณ', 'เล่น', 'มือถือ'],
         ['ส่วน', 'น้อง', 'เขียน', 'โปรแกรม']]
     """
-    from .crfcls import segment
+    if not doc or not isinstance(doc, str):
+        return []
+
+    from pythainlp.tokenize.crfcls import segment
 
     return segment(doc)
 
@@ -74,6 +77,9 @@ def word_tokenize(
         * *deepcut* - wrapper for
           `DeepCut <https://github.com/rkcosmos/deepcut>`_,
           learning-based approach
+        * *nercut* - Dictionary-based maximal matching word segmentation,
+          constrained with Thai Character Cluster (TCC) boundaries,
+          and combining tokens that are parts of the same named-entity.
 
     :Note:
         - The parameter **custom_dict** can be provided as an argument \
@@ -132,27 +138,27 @@ def word_tokenize(
     segments = []
 
     if engine == "newmm" or engine == "onecut":
-        from .newmm import segment
+        from pythainlp.tokenize.newmm import segment
 
         segments = segment(text, custom_dict)
     elif engine == "newmm-safe":
-        from .newmm import segment
+        from pythainlp.tokenize.newmm import segment
 
         segments = segment(text, custom_dict, safe_mode=True)
     elif engine == "attacut":
-        from .attacut import segment
+        from pythainlp.tokenize.attacut import segment
 
         segments = segment(text)
     elif engine == "longest":
-        from .longest import segment
+        from pythainlp.tokenize.longest import segment
 
         segments = segment(text, custom_dict)
     elif engine == "mm" or engine == "multi_cut":
-        from .multi_cut import segment
+        from pythainlp.tokenize.multi_cut import segment
 
         segments = segment(text, custom_dict)
     elif engine == "deepcut":  # deepcut can optionally use dictionary
-        from .deepcut import segment
+        from pythainlp.tokenize.deepcut import segment
 
         if custom_dict:
             custom_dict = list(custom_dict)
@@ -160,7 +166,11 @@ def word_tokenize(
         else:
             segments = segment(text)
     elif engine == "icu":
-        from .pyicu import segment
+        from pythainlp.tokenize.pyicu import segment
+
+        segments = segment(text)
+    elif engine == "nercut":
+        from pythainlp.tokenize.nercut import segment
 
         segments = segment(text)
     else:
@@ -244,7 +254,7 @@ def sent_tokenize(
     segments = []
 
     if engine == "crfcut":
-        from .crfcut import segment
+        from pythainlp.tokenize.crfcut import segment
 
         segments = segment(text)
     elif engine == "whitespace":
@@ -291,6 +301,7 @@ def subword_tokenize(
     **Options for engine**
         * *tcc* (default) -  Thai Character Cluster (Theeramunkong et al. 2000)
         * *etcc* - Enhanced Thai Character Cluster (Inrut et al. 2001)
+        * *wangchanberta* - SentencePiece from wangchanberta model.
 
     :Example:
 
@@ -310,7 +321,7 @@ def subword_tokenize(
         # output: ['ค', 'วา', 'ม', 'แป', 'ล', 'ก', 'แย', 'ก',
         'และ', 'พัฒ','นา', 'กา', 'ร']
 
-    Tokenize text into subword based on *etcc* **(Work In Progress)**::
+    Tokenize text into subword based on *etcc*::
 
         text_1 = "ยุคเริ่มแรกของ ราชวงศ์หมิง"
         text_2 = "ความแปลกแยกและพัฒนาการ"
@@ -320,14 +331,27 @@ def subword_tokenize(
 
         subword_tokenize(text_2, engine='etcc')
         # output: ['ความแปลกแยกและ', 'พัฒ', 'นาการ']
+
+    Tokenize text into subword based on *wangchanberta*::
+
+        text_1 = "ยุคเริ่มแรกของ ราชวงศ์หมิง"
+        text_2 = "ความแปลกแยกและพัฒนาการ"
+
+        subword_tokenize(text_1, engine='wangchanberta')
+        # output: ['▁', 'ยุค', 'เริ่มแรก', 'ของ', '▁', 'ราชวงศ์', 'หมิง']
+
+        subword_tokenize(text_2, engine='wangchanberta')
+        # output: ['▁ความ', 'แปลก', 'แยก', 'และ', 'พัฒนาการ']
     """
     if not text or not isinstance(text, str):
         return []
 
     if engine == "tcc":
-        from .tcc import segment
+        from pythainlp.tokenize.tcc import segment
     elif engine == "etcc":
-        from .etcc import segment
+        from pythainlp.tokenize.etcc import segment
+    elif engine == "wangchanberta":
+        from pythainlp.wangchanberta import segment
     else:
         raise ValueError(
             f"""Tokenizer \"{engine}\" not found.
@@ -394,7 +418,7 @@ def syllable_tokenize(
                 )
             )
     elif engine == "ssg":
-        from .ssg import segment
+        from pythainlp.tokenize.ssg import segment
 
         segments = segment(text)
     else:
